<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>Filtra:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>Seleziona il carattere del terminale</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>Carattere:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>Dimensione:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>Anteprima</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Bookmarks</source>
        <translation>Segnalibri</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="192"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>Premi %1 per mostrare il terminale.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="421"/>
        <source>Fullscreen</source>
        <translation>Schermo intero</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="234"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>&amp;Pulisci terminale attivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="241"/>
        <source>&amp;Next Tab</source>
        <translation>&amp;Prossima scheda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="244"/>
        <source>&amp;Previous Tab</source>
        <translation>Scheda p&amp;recedente</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <source>&amp;Previous Tab in History</source>
        <translation>&amp;Tab Precedente in cronologia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="250"/>
        <source>&amp;Next Tab in History</source>
        <translation>&amp;Tab Successivo in Cronologia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="253"/>
        <source>Move Tab &amp;Left</source>
        <translation>&amp;Sposta scheda a sinistra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Move Tab &amp;Right</source>
        <translation>Sposta scheda a &amp;destra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Tab</source>
        <translation>Scheda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>Go to</source>
        <translation>Vai a</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="275"/>
        <source>Split Terminal &amp;Horizontally</source>
        <translation>Dividi terminale &amp;orizzontalmente</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Split Terminal &amp;Vertically</source>
        <translation>Dividi terminale &amp;verticalmente</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>&amp;Collassa sottoterminale</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>&amp;Top Subterminal</source>
        <translation>&amp;Sottoterminale in cima</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="289"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>Sottoterminale in &amp;fondo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>L&amp;eft Subterminal</source>
        <translation>Sottoterminale a &amp;sinistra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>R&amp;ight Subterminal</source>
        <translation>Sottoterminale a &amp;destra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>Copy &amp;Selection</source>
        <translation>&amp;Copia selezione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="305"/>
        <source>Paste Clip&amp;board</source>
        <translation>&amp;Incolla dagli appunti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Paste S&amp;election</source>
        <translation>&amp;Incolla selezione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>Zoom &amp;in</source>
        <translation>&amp;Ingrandisci</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="314"/>
        <source>Zoom &amp;out</source>
        <translation>&amp;Diminuisci</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>Zoom rese&amp;t</source>
        <translation>&amp;Ripristina zoom</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="322"/>
        <source>&amp;Find...</source>
        <translation>&amp;Cerca...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="325"/>
        <source>Handle history...</source>
        <translation>Gestisci cronologia...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>&amp;Save Session</source>
        <translation>&amp;Salva sessione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>&amp;Load Session</source>
        <translation>&amp;Carica sessione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="346"/>
        <source>&amp;Toggle Menu</source>
        <translation>&amp;Mostra/nascondi menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="351"/>
        <source>Rename session</source>
        <translation>Rinomina sessione</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>&amp;New Tab</source>
        <translation>&amp;Nuova scheda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>New Tab From &amp;Preset</source>
        <translation>Nuova scheda &amp;preconfigurata</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>1 &amp;Terminal</source>
        <translation>1 &amp;terminale</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>2 terminali &amp;orizzontali</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>2 terminali &amp;verticali</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>4 Terminal&amp;s</source>
        <translation>4 terminal&amp;i</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>&amp;Close Tab</source>
        <translation>&amp;Chiudi scheda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="380"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nuova finestra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferenze...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Nascondi decorazione della finestra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>&amp;Show Tab Bar</source>
        <translation>&amp;Mostra barra delle schede</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="427"/>
        <source>Toggle Bookmarks</source>
        <translation>Mostra/nascondi segnalibri</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>&amp;Bottom</source>
        <translation>in &amp;fondo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>&amp;Top</source>
        <translation>in &amp;cima</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <location filename="../mainwindow.cpp" line="473"/>
        <source>&amp;Right</source>
        <translation>a &amp;destra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>&amp;Left</source>
        <translation>a &amp;sinistra</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="456"/>
        <source>&amp;Tabs Layout</source>
        <translation>&amp;Posizione delle schede</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>&amp;None</source>
        <translation>&amp;Nessuno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="490"/>
        <source>S&amp;crollbar Layout</source>
        <translation>&amp;Posizione barra di scorrimento</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>&amp;BlockCursor</source>
        <translation>&amp;Blocco verticale</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="504"/>
        <source>&amp;UnderlineCursor</source>
        <translation>&amp;Sottolineatura</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="505"/>
        <source>&amp;IBeamCursor</source>
        <translation>Barra &amp;verticale</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="522"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>&amp;Tipo di cursore</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="622"/>
        <source>Exit QTerminal</source>
        <translation>Esci da QTerminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Do not ask again</source>
        <translation>Non chiedermelo di nuovo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="632"/>
        <source>Are you sure you want to exit?</source>
        <translation>Sei sicuro di voler uscire?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>A lightweight multiplatform terminal emulator</source>
        <translation>Un emulatore di terminale multipiattaforma e leggero</translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../propertiesdialog.cpp" line="155"/>
        <source>No scrollbar</source>
        <translation>Nessuna barra di scorrimento</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="155"/>
        <location filename="../propertiesdialog.cpp" line="161"/>
        <source>Left</source>
        <translation>Sinistra</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="155"/>
        <location filename="../propertiesdialog.cpp" line="161"/>
        <source>Right</source>
        <translation>Destra</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="161"/>
        <source>Top</source>
        <translation>Alto</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="161"/>
        <source>Bottom</source>
        <translation>Basso</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="174"/>
        <source>BlockCursor</source>
        <translation>Blocco</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="174"/>
        <source>UnderlineCursor</source>
        <translation>Sottolineatura</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="174"/>
        <source>IBeamCursor</source>
        <translation>Barra verticale</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="192"/>
        <source>No move</source>
        <translation>Nessuna</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="192"/>
        <source>Scrolling to top</source>
        <translation>Scrollare all&apos;inizio</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="192"/>
        <source>Scrolling to bottom</source>
        <translation>Scrollare in fondo</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="390"/>
        <source>Images (*.bmp *.jpg *.png *.svg *.xpm)</source>
        <translation>Immagini (*.bmp *.jpg *.png *.svg *.xpm)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="199"/>
        <location filename="../propertiesdialog.cpp" line="294"/>
        <source>System Default</source>
        <translation>Predefinito dal sistema</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="389"/>
        <source>Choose a background image</source>
        <translation>Seleziona immagine di fondo</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="466"/>
        <source>Open or create bookmarks file</source>
        <translation>Apri o crea file di segnalibri</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>Preferenze del terminale</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="31"/>
        <source>Appearance</source>
        <translation>Aspetto</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="39"/>
        <location filename="../forms/propertiesdialog.ui" line="611"/>
        <source>Behavior</source>
        <translation>Comportamento</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="47"/>
        <source>Shortcuts</source>
        <translation>Scorciatoie</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="55"/>
        <source>Dropdown</source>
        <translation>Terminale a discesa</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="63"/>
        <source>Bookmarks</source>
        <translation>Segnalibri</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="275"/>
        <source>Color scheme</source>
        <translation>Schema colori</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="184"/>
        <source>&amp;Change...</source>
        <translation>&amp;Modifica...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="238"/>
        <source>Widget style</source>
        <translation>Stile elementi</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="371"/>
        <source>Scrollbar position</source>
        <translation>Posizione barra di scorrimento</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="454"/>
        <source>Tabs position</source>
        <translation>Posizione delle schede</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="194"/>
        <source>Show the menu bar</source>
        <translation>Mostra barra del menu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="258"/>
        <source>Hide tab bar with only one tab</source>
        <translation>Nascondi barra con una scheda sola</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="404"/>
        <source>Show a border around the current terminal</source>
        <translation>Mostra un bordo intorno al terminale attuale</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="394"/>
        <source>Application transparency</source>
        <translation>Trasparenza dell&apos;applicazione</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="381"/>
        <source>Terminal transparency</source>
        <translation>Trasparenza del terminale</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="117"/>
        <location filename="../forms/propertiesdialog.ui" line="425"/>
        <source> %</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="204"/>
        <source>Start with preset:</source>
        <translation>Avvia con preconfigurazione:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="215"/>
        <source>None (single terminal)</source>
        <translation>Nessuna (terminale singolo)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="220"/>
        <source>2 terminals horizontally</source>
        <translation>2 terminali orizzontalmente</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="225"/>
        <source>2 terminals vertically</source>
        <translation>2 terminali verticalmente</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="230"/>
        <source>4 terminals</source>
        <translation>4 terminali</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="148"/>
        <source>Font</source>
        <translation>Carattere</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="335"/>
        <source>Cursor shape</source>
        <translation>Forma Cursore</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="464"/>
        <source>Change window title based on current terminal</source>
        <translation>Cambia titolo della finestra in base al terminale corrente</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="481"/>
        <source>Change window icon based on current terminal</source>
        <translation>Cambia icona della finestra in base al terminale corrente</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="418"/>
        <source>Enable bi-directional text support</source>
        <translation>Abilita supporto al testo bi-direzionale</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="265"/>
        <source>Background image:</source>
        <translation>Immagine di sfondo:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="290"/>
        <source>Select</source>
        <translation>Seleziona</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="488"/>
        <source>Show terminal size on resize</source>
        <translation>Mostra dimensione terminale durante il ridimensionamento</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="471"/>
        <source>Fixed tab width:</source>
        <translation>Larghezza scheda fissa:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="411"/>
        <location filename="../forms/propertiesdialog.ui" line="444"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="361"/>
        <source>Show close button on each tab</source>
        <translation>Mostra tasto chiudi su ogni tab</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="248"/>
        <source>Terminal margin</source>
        <translation>Margine del Terminale</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="498"/>
        <source>Use box drawing characters contained in the font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="505"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation>Acceleratori sono attivati con Alt e possono interferire con il terminale.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="508"/>
        <source>No menu bar accelerator</source>
        <translation>Nessun acceleratore nella barra del menu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="586"/>
        <source>Emulation</source>
        <translation>Emulazione</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="711"/>
        <source>Action after paste</source>
        <translation>Azione dopo incolla</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="748"/>
        <source>Confirm multiline paste</source>
        <translation>Chiedi conferma per incollare testo con più righe</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="789"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>Elimina fine riga nel testo incollato</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="724"/>
        <source>Open new terminals in current working directory</source>
        <translation>Apri terminali nuovi nella directory attuale</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="755"/>
        <source>Save Size when closing</source>
        <translation>Salva dimensioni alla chiusura</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="796"/>
        <source>Save Position when closing</source>
        <translation>Salva posizione alla chiusura</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="772"/>
        <source>Ask for confirmation when closing</source>
        <translation>Chiedi conferma per la chiusura</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="816"/>
        <source>Unlimited history</source>
        <translation>Cronologia illimitata</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="782"/>
        <source>History size (in lines)</source>
        <translation>Dimensione cronologia (linee)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="741"/>
        <source>Default $TERM</source>
        <translation>$TERM di default</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="632"/>
        <source>Start with this size:</source>
        <translation>Avvia con questa dimensione:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="299"/>
        <source>Background mode:</source>
        <translation>Modalità sfondo:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="307"/>
        <source>None</source>
        <translation>Nessuno</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="312"/>
        <source>Stretch</source>
        <translation type="unfinished">Allarga</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="317"/>
        <source>Zoom</source>
        <translation>Ingrandisci</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="322"/>
        <source>Fit</source>
        <translation>Adatta</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="327"/>
        <source>Center</source>
        <translation>Centra</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="495"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="515"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation>Cambia l&apos;uso del grassetto per visualizzare i colori intensi</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="518"/>
        <source>Use bold font face for intense colors</source>
        <translation>Visualizza i colori intensi in grassetto</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="525"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Nascondi decorazione della finestra</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="595"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Quale comportamento da emulare. Questo non deve corrispondere al sistema operativo in uso.&lt;/p&gt;&lt;p&gt;Se si è insicuri usare l&apos;emulazione &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="617"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="620"/>
        <source>Handle history command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="639"/>
        <location filename="../forms/propertiesdialog.ui" line="653"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="660"/>
        <source>Get current size</source>
        <translation>Determina dimensione attuale</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="731"/>
        <source>Open new tab to the right of the active tab</source>
        <translation>Apri schede nuove a destro della scheda attuale</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="734"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation>Se non è spuntato la scheda nuova si apre ultima sulla destra</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="762"/>
        <source>Close tab on middle-click</source>
        <translation>Chiudi scheda con tasto centrale</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="823"/>
        <source>Forcefully disable bracketed paste mode</source>
        <translation>Disabilita modalità incolla tra parentesi</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="826"/>
        <source>Bracketed paste mode is useful for pasting multiline strings.</source>
        <translation>La modalità incolla tra parentesi può essere utile per stringe multi-righe.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="844"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation>Per modificare una scorciatoia:
1. Clic doppio sulla combinazione
2. Premere la scorciatoia/combinazione desiderata
3. Cliccare una scorciatoia o premere Invio

Per rimuovere una scorciatoia al punto 2 premere maiusc, alt o win</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="874"/>
        <source>Shortcut</source>
        <translation>Scorciatoia</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="879"/>
        <source>Key</source>
        <translation>Chiave</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="891"/>
        <source>Show on start</source>
        <translation>Mostra all&apos;avvio</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="898"/>
        <source>Size</source>
        <translation>Dimensione</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="909"/>
        <source>Height</source>
        <translation>Altezza</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="919"/>
        <location filename="../forms/propertiesdialog.ui" line="936"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="926"/>
        <source>Width</source>
        <translation>Larghezza</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="950"/>
        <source>Shortcut:</source>
        <translation>Scorciatoia:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="982"/>
        <source>Edit bookmark file contents</source>
        <translation>Modifica contenuto file segnalibro</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1004"/>
        <source>Enable bookmarks</source>
        <translation>Attiva segnalibri</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1013"/>
        <source>Bookmark file</source>
        <translation>File segnalibro</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1026"/>
        <source>Find...</source>
        <translation>Cerca...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1035"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>Si può specificare la posizione personalizzata per i segnalibri. Permette una condivisione facile usando servizi come OwnCloud o Dropbox.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="108"/>
        <source>Local Bookmarks</source>
        <translation>Segnalibri locali</translation>
    </message>
    <message>
        <location filename="../bookmarkswidget.cpp" line="166"/>
        <source>Synchronized Bookmarks</source>
        <translation>Segnalibri sincronizzati</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="78"/>
        <location filename="../tabwidget.cpp" line="232"/>
        <source>Shell No. %1</source>
        <translation>Shell N° %1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="200"/>
        <source>Tab name</source>
        <translation>Nome scheda</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="201"/>
        <source>New tab name:</source>
        <translation>Nuovo nome scheda:</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="221"/>
        <source>Select new tab title color</source>
        <translation>Seleziona colore del titolo del nuovo tab</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="242"/>
        <source>Close session</source>
        <translation>Chiudi sessione</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="244"/>
        <source>Change title color</source>
        <translation>Cambia colore titolo</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="79"/>
        <source>Load Session</source>
        <translation>Carica Sessione</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="80"/>
        <source>List of saved sessions:</source>
        <translation>Lista delle sessioni salvate:</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Finestra principale</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>&amp;Azioni</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>&amp;Visualizza</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>&amp;Modifica</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>&amp;Informazioni...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>Informazioni su &amp;Qt...</translation>
    </message>
</context>
</TS>
